Tutorial
========

After installation, you are ready to start testing the convenience and power
of the package.

Before using, type

>>> import shorttext

You will get the message that `Theano`, `Tensorflow` or `CNTK` backend is used for `keras`. Refer to `Keras Backend
<https://keras.io/backend/>`_ for information about switching backends.

.. toctree::
   :maxdepth: 2

   tutorial_dataprep
   tutorial_textpreprocessing
   tutorial_dtm
   tutorial_charbaseonehot
   tutorial_topic
   tutorial_wordembed
   tutorial_sumvec
   tutorial_nnlib
   tutorial_maxent
   tutorial_charbaseseq2seq
   tutorial_stacking
   tutorial_metrics
   tutorial_spell


Home: :doc:`index`
